import { Injectable } from '@angular/core';
import {
  ActivatedRouteSnapshot,
  Resolve,
  Router,
  RouterStateSnapshot,
} from '@angular/router';
import { MemberService } from 'app/modules/polyglot/member/services/member.service';
import { ListMembersResponse } from 'app/modules/proto/c2se/member_pb';
import { GetMemberResponse } from 'app/modules/proto/c2se/member_pb';

import { Observable } from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class ListMemberResolver implements Resolve<any> {
  /**
   * Constructor
   */
  constructor(private _router: Router, private _memberService: MemberService) {}

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Resolver
   *
   * @param route
   * @param state
   */

  resolve(
    route: ActivatedRouteSnapshot,
    state: RouterStateSnapshot
  ):
    | Observable<ListMembersResponse.Result>
    | Promise<ListMembersResponse.Result>
    | ListMembersResponse.Result {
    return this._memberService.listMembers();
  }
}

@Injectable({
  providedIn: 'root',
})
export class MemberResolver implements Resolve<any> {
  /**
   * Constructor
   */
  constructor(private _router: Router, private _memberService: MemberService) {}

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Resolver
   *
   * @param route
   * @param state
   */

  resolve(
    route: ActivatedRouteSnapshot,
    state: RouterStateSnapshot
  ):
    | Observable<GetMemberResponse.Result>
    | Promise<GetMemberResponse.Result>
    | GetMemberResponse.Result {
    let memberId = route.paramMap.get('id');
    if (!memberId) {
      console.error('user.resolver memberId is null');
    }
    return this._memberService.getMember(memberId!);
  }
}
